Name:      icu
Version:   4.4
Release:   1
Summary:   International Components for Unicode
Group:     Development/Tools
License:   MIT
URL:       http://www.icu-project.org/
Source0:   http://download.icu-project.org/files/icu4c/4.4/icu4c-4_4-src.tgz
Source1:   http://download.icu-project.org/files/icu4c/4.4/icu4c-src-4_4.md5
Source2:   http://download.icu-project.org/files/icu4c/4.4/icu4c-4_4-docs.zip
Patch1:    icu-3.4-multiarchdevel.patch
Patch2:    icu.icu6284.strictalias.patch
Patch3:    icu.6995.kannada.patch
Patch4:    icu.XXXX.buildfix.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: autoconf, make, patch, doxygen
Requires: lib%{name} = %{version}-%{release}

%description
Tools and utilities for developing with %{name}.


%package -n lib%{name}
Summary: International Components for Unicode - libraries
Group:   System Environment/Libraries

%description -n lib%{name}
The International Components for Unicode (ICU) libraries provide
robust and full-featured Unicode services on a wide variety of
platforms. ICU supports the most current version of the Unicode
standard, and they provide support for supplementary Unicode
characters (needed for GB 18030 repertoire support).
As computing environments become more heterogeneous, software
portability becomes more important. ICU lets you produce the same
results across all the various platforms you support, without
sacrificing performance. It offers great flexibility to extend and
customize the supplied services.


%package  -n lib%{name}-devel
Summary:  Development files for International Components for Unicode
Group:    Development/Libraries
Requires: lib%{name} = %{version}-%{release}
Requires: pkg-config

%description -n lib%{name}-devel
Includes and definitions for developing with %{name}.


%package -n lib%{name}-doc
Summary: Documentation for International Components for Unicode
Group:   Documentation

%description -n lib%{name}-doc
%{summary}.


%prep
%setup -q -n %{name}
export PATH=/opt/freeware/bin:$PATH
%patch1 -p1 -b .multiarchdevel
%patch2 -p1 -b .icu6284.strictalias.patch
%patch3 -p1 -b .icu6995.kannada.patch
%patch4 -p1 -b .icuXXXX.buildfix.patch

mkdir docs
cd docs
unzip %{SOURCE2}
cd ..
chown -R root.system docs
chmod -R u+w docs
chmod -R og-w docs
chmod -R og+r docs


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export OBJECT_MODE=64
cd source
autoconf
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --enable-release \
    --disable-samples \
    --disable-tests \
    --with-library-bits=64 \
    --with-data-packaging=library

gmake # %{?_smp_mflags} # -j(X>1) does not work

for f in lib/*.a ; do
    ${AR} -x ${f}
done

gmake distclean

# now build the 32-bit version
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --enable-release \
    --disable-samples \
    --disable-tests \
    --with-library-bits=32 \
    --with-data-packaging=library

gmake # %{?_smp_mflags} # -j(X>1) does not work

# required?
slibclean
# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
for f in lib*.so; do
    ${AR} -q lib/`basename ${f} .so`.a ./${f}
done


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd source
gmake install DESTDIR=${RPM_BUILD_ROOT}

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :
/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_sbindir}/* || :


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/license.html 32bit/readme.html
%{_bindir}/derb
%{_bindir}/genbrk
%{_bindir}/gencfu
%{_bindir}/gencnval
%{_bindir}/genctd
%{_bindir}/genrb
%{_bindir}/makeconv
%{_bindir}/pkgdata
%{_bindir}/uconv
%{_sbindir}/*
%{_mandir}/man1/derb.1*
%{_mandir}/man1/gencnval.1*
%{_mandir}/man1/genrb.1*
%{_mandir}/man1/genbrk.1*
%{_mandir}/man1/genctd.1*
%{_mandir}/man1/makeconv.1*
%{_mandir}/man1/pkgdata.1*
%{_mandir}/man1/uconv.1*
%{_mandir}/man8/*.8*


%files -n lib%{name}
%defattr(-,root,system,-)
%{_libdir}/*.a


%files -n lib%{name}-devel
%defattr(-,root,system,-)
%doc 32bit/license.html
%{_bindir}/%{name}-config
%{_bindir}/icuinfo
%{_mandir}/man1/%{name}-config.1*
%{_includedir}/*
%{_libdir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}


%files -n lib%{name}-doc
%defattr(-,root,system,-)
%doc docs/*


%changelog
* Fri Apr 09 2010 Michael Perzl <michael@perzl.org> - 4.4-1
- first version for AIX5L v5.1 and higher
